@@ -43,7 +43,7 @@ $EXPORT_TAGS{ all } = [@EXPORT_OK];
 our $DIE_ON_ERROR = 0;
 our $PROMOTE_N32 = 1;
 
-our $VERSION = '3.025';
+our $VERSION = '3.026';
 
 sub IP {
     return Net::IPAddress::Util->new($_[0]);
@@ -53,6 +53,9 @@ sub new {
     my $self = shift;
     my $class = ref($self) || $self;
     my ($address) = @_;
+    unless (defined $address) {
+        return ERROR("Invalid argument undef() provided");
+    }
     my $normal = [ ];
     if (ref($address) eq 'ARRAY' && @$address == 16) {
         $normal = $address;
@@ -131,7 +134,7 @@ sub new {
         return bless { address => $address } => $class;
     }
     else {
-        confess("I can't handle `$address', a(n) " . (ref($address) || 'bare scalar'));
+        return ERROR("Invalid argument `$address', a(n) " . (ref($address) || 'bare scalar') . ' provided');
     }
     return bless { address => pack('C16', @$normal) } => $class;
 }
